@@ -207,7 +207,7 @@ PyObject* _Nullable PyObjCUnicode_New(NSString* value)
 
     length = [value length];
 
-    characters = PyObject_MALLOC(sizeof(unichar) * (length + 1));
+    characters = PyObject_Malloc(sizeof(unichar) * (length + 1));
     if (characters == NULL) { // LCOV_BR_EXCL_LINE
         // LCOV_EXCL_START
         PyErr_NoMemory();
@@ -215,6 +215,7 @@ PyObject* _Nullable PyObjCUnicode_New(NSString* value)
         // LCOV_EXCL_STOP
     }
 
+    bool have_exception = false;
     Py_BEGIN_ALLOW_THREADS
         @try {
             range = NSMakeRange(0, length);
@@ -223,13 +224,15 @@ PyObject* _Nullable PyObjCUnicode_New(NSString* value)
             characters[length] = 0;
 
         } @catch (NSObject* localException) {
-            PyMem_Free(characters);
-            characters = NULL;
+            have_exception = true;
             PyObjCErr_FromObjC(localException);
         }
     Py_END_ALLOW_THREADS
 
-    if (characters == NULL) {
+    if (have_exception) {
+        PyObject_Free(characters);
+        characters = NULL;
+
         return NULL;
     }
 
@@ -394,10 +397,16 @@ PyObject* _Nullable PyObjCUnicode_New(NSString* value)
         }
         *ucs4_cur     = 0;
         ascii->length = length - nr_surrogates;
+
+#if SIZEOF_WCHAR_T != 4
+#error "Code assumes sizeof(wchar_t) == 4
+#endif
+        ascii->wstr          = (wchar_t*)result->base.data.ucs4;
+        compact->wstr_length = ascii->length;
     }
 
     if (characters != NULL) {
-        PyObject_DEL(characters);
+        PyObject_Free(characters);
         characters = NULL;
     }
 
@@ -414,7 +423,7 @@ PyObject* _Nullable PyObjCUnicode_New(NSString* value)
 error:
     // LCOV_EXCL_START
     Py_DECREF((PyObject*)result);
-    PyMem_Free(characters);
+    PyObject_Free(characters);
     characters = NULL;
     PyErr_NoMemory();
     return NULL;
